@@ -1,15 +1,17 @@
-# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2024 Mario S. Könz; License: MIT
 import django
 from django.conf import settings
 
 from . import _create_django_model
 from . import _decorator
 from . import _inspect_dataclass
+from . import _storage_mixin
 from . import _store_setup
 from . import _sync_store
 from ._create_django_model import *
 from ._decorator import *
 from ._inspect_dataclass import *
+from ._storage_mixin import *
 from ._store_setup import *
 from ._sync_store import *
 
@@ -20,7 +22,8 @@ __all__ = (
     + _store_setup.__all__
     + _create_django_model.__all__
     + _inspect_dataclass.__all__
+    + _storage_mixin.__all__
 )
 
 
-__version__ = "1.9.0"
+__version__ = "2.7.1"
