@@ -1,4 +1,4 @@
-# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2024 Mario S. Könz; License: MIT
 import dataclasses as dc
 import typing as tp
 
@@ -16,8 +16,17 @@ class InspectDataclass:
         list[str] | None,
         dict[str, dict[str, tp.Any]] | None,
         list[str] | None,
+        str | None,
+        str | None,
     ]:
-        pk_key, unique_together, extra_kwgs, ordering = None, None, None, None
+        pk_key, unique_together, extra_kwgs, ordering, app_label, db_table = (
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+        )
         if hasattr(self.dataclass, "Meta"):
             meta = self.dataclass.Meta
             if hasattr(meta, "primary_key"):
@@ -33,11 +42,17 @@ class InspectDataclass:
             if hasattr(meta, "ordering"):
                 ordering = meta.ordering
                 assert isinstance(ordering, list)
+            if hasattr(meta, "app_label"):
+                app_label = meta.app_label
+                assert isinstance(app_label, str)
+            if hasattr(meta, "db_table"):
+                db_table = meta.db_table
+                assert isinstance(db_table, str)
 
-        return pk_key, unique_together, extra_kwgs, ordering
+        return pk_key, unique_together, extra_kwgs, ordering, app_label, db_table
 
     def get_identifying_parameter(self) -> set[str]:
-        pk_key, unique_together, _, _ = self.extract_meta()
+        pk_key, unique_together, *_ = self.extract_meta()
         res = set()
         if pk_key is not None:
             res.add(pk_key)
@@ -53,4 +68,4 @@ class InspectDataclass:
         if field.default_factory != dc.MISSING:
             assert field.default is dc.MISSING
             return field.default_factory
-        return None
+        return dc.MISSING
