@@ -1,4 +1,4 @@
-# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2024 Mario S. Könz; License: MIT
 import typing as tp
 
 T = tp.TypeVar("T")  # pylint: disable=invalid-name
@@ -11,8 +11,16 @@ class BackendStoreProtocol(tp.Protocol):
     def load_all(self, dataclass: type[T], **filter_kwgs: tp.Any) -> tp.Iterator[T]:
         pass  # pragma: no cover
 
-    def parse(self, backend_obj: tp.Any) -> tp.Any:
+    def parse(
+        self,
+        backend_obj: tp.Any,
+        defer: tuple[str, ...] = tuple(),
+        only: tuple[str, ...] = tuple(),
+    ) -> tp.Any:
         pass  # pragma: no cover
 
     def backend_manager(self, dataclass: type[T]) -> tp.Any:
         pass  # pragma: no cover
+
+    def reverse_set(self, obj: T, relation: str) -> set[tp.Any]:
+        pass  # pragma: no cover
