@@ -1,4 +1,4 @@
-# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2024 Mario S. Könz; License: MIT
 import collections
 import contextlib
 import io
@@ -9,6 +9,7 @@ import django
 from django.apps import apps
 from django.conf import settings
 from django.core.management import call_command
+from django.core.signals import setting_changed
 from django.db import connections
 
 from ._decorator import BACKEND_LINKER
@@ -44,6 +45,7 @@ def set_store(
 def set_file_backend(media_root: Path) -> None:
     django_config()
     settings.MEDIA_ROOT = media_root
+    setting_changed.send(None, setting="MEDIA_ROOT")
 
 
 @contextlib.contextmanager
@@ -63,6 +65,7 @@ def django_setup(identifier: str) -> tp.Iterator[dict[str, tp.Any]]:
         apps.apps_ready = apps.models_ready = apps.loading = apps.ready = False
         apps.clear_cache()
         apps.populate(settings.INSTALLED_APPS)
+        setting_changed.send(None, setting="INSTALLED_APPS")
 
         try:
             with contextlib.redirect_stdout(io.StringIO()):
@@ -83,6 +86,7 @@ def django_config() -> None:
             USE_TZ=True,
             DEFAULT_AUTO_FIELD="django.db.models.BigAutoField",
         )
+        settings.STORAGES["default"] = dict(BACKEND="admem.DirectoryFSS")
         django.setup()
 
 
